@@ -497,7 +497,7 @@ if __name__ =='__main__':
 
 
         plt.colorbar()
-        plt.show()
+
 
 
 
@@ -520,9 +520,10 @@ if __name__ =='__main__':
 
 
     #x,s = load_music()
-    #x,s = librosa.load( '/home/nnanos/Downloads/glockenspiel.wav',sr=44100 )
-    x,s = librosa.load( '/home/nnanos/Downloads/hancock.wav',sr=44100 )
-    x = x[:44100*6]    
+    x,s = librosa.load( '/home/nnanos/Downloads/glockenspiel.wav',sr=44100 )
+    # x,s = librosa.load( '/home/nnanos/Downloads/hancock.wav',sr=44100 )
+    # x = x[:44100*6]    
+
     # x1,s = librosa.load( "/home/nnanos/Desktop/sounds/C4.wav",sr=44100)
     # x2,s = librosa.load( "/home/nnanos/Desktop/sounds/Snare 1.wav",sr=44100)
     # x2 = np.concatenate((x2,np.zeros(len(x1)-len(x2))))
@@ -531,10 +532,11 @@ if __name__ =='__main__':
     #x = x1+x2
 
     #params
-    min_scl = 128
+    min_scl = 512
     multiproc = True
     nb_processes = 6
-    ovrlp_fact = 1/10
+    ovrlp_fact = 0.5
+
     #middle_window = sg.tukey
     middle_window = np.hanning
     matrix_form = False
